<template>
  <div>
    <el-dialog
      v-model="dialogVisible"
      :title="title"
      width="600"
      :close-on-click-modal="false"
      :before-close="handleClose"
    >
      <el-form
        ref="formRef"
        style="max-width: 400px; margin: 0 auto"
        :model="formData"
        :rules="rules"
        label-width="auto"
      >
        <el-form-item label="客户名称" prop="supplierName">
          <el-input
            v-model="formData.supplierName"
            placeholder="请输入供货商名称"
          />
        </el-form-item>
        <el-form-item label="纳税人识别号" prop="identifyNumber">
          <el-input
            v-model="formData.identifyNumber"
            placeholder="请输入纳税人识别号"
          />
        </el-form-item>
        <el-form-item label="经营地址" prop="address">
          <el-cascader
            placeholder="请选择经营地址"
            size="default"
            :options="addressSelectOptions"
            v-model="formData.address"
            @change="handleChange"
          >
          </el-cascader>
        </el-form-item>
        <el-form-item label="详细地址" prop="addressDetail">
          <el-input
            v-model="formData.addressDetail"
            placeholder="请输入客户详细地址"
          />
        </el-form-item>
        <el-form-item label="银行账户" prop="bankAccount">
          <el-input
            v-model="formData.bankAccount"
            placeholder="请输入银行账户"
          />
        </el-form-item>
        <el-form-item label="开户行" prop="bank">
          <el-input v-model="formData.bank" placeholder="请输入开户行" />
        </el-form-item>
        <el-form-item label="联系人" prop="contacts">
          <el-input v-model="formData.contacts" placeholder="请输入联系人" />
        </el-form-item>
        <el-form-item label="联系人电话" prop="contactsPhone">
          <el-input
            v-model="formData.contactsPhone"
            placeholder="请输入联系人电话"
          />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" @click="submitForm"> 确定 </el-button>
          <el-button v-if="addOrEdit === 'edit'" @click="resetForm"
            >重置</el-button
          >
          <el-button v-if="addOrEdit === 'add'" @click="cancelForm"
            >取消</el-button
          >
        </el-form-item>
      </el-form>
    </el-dialog>
  </div>
</template>

<script setup>
import { ref, watch, defineProps, onMounted } from "vue";
import addressList from "@/api/jsonApi/areaList.json";
const props = defineProps({
  beforeClose: {
    type: Function,
    default: () => {},
  },
  form: {
    type: Object,
    default: () => ({}),
  },
  addOrEdit: {
    type: String,
    default: "add",
  },
  title: {
    type: String,
    default: "",
  },
});

const emit = defineEmits(["submit", "handleBeforeClose"]);

onMounted(()=>{
  addressSelectOptions.value = mapAddress(addressList);
})
// 地址选择数据
const addressSelectOptions = ref([]);
// 处理地址数据转换
function mapAddress(list) {
  return list.map(item => ({
    value: item.no,
    label: item.name,
    children: item.children ? mapAddress(item.children) : undefined
  }));
}
// 表单引用
const formRef = ref(null);
// 表单数据
const formData = ref({ ...props.form });
// 弹窗可见性
const dialogVisible = defineModel("coalQualityMaintenanceDialogFormVisible", {
  required: true,
  type: Boolean,
});
// 监听外部传入的表单数据变化
watch(
  () => props.form,
  (newVal) => {
    formData.value = { ...newVal };
  },
  { deep: true }
);

// 监听内部弹窗状态变化
watch(
  () => dialogVisible.value,
  (newVal) => {
    emit("update:coalQualityMaintenanceDialogFormVisible", newVal);
  }
);
// 处理地址选择变化
const handleChange = (value) => {
  console.log(value);
};
// 提交表单
const submitForm = async () => {
  if (!formRef.value) return;
  await formRef.value.validate((valid, fields) => {
    if (valid) {
      emit("submit", formData.value);
    }
  });
};
// 取消表单
const cancelForm = () => {
  emit("update:coalQualityMaintenanceDialogFormVisible", false);
  formData.value = {};
};
// 重置表单
const resetForm = () => {
  if (!formRef.value) return;
  formRef.value.resetFields();
};
// 关闭弹窗
const handleClose = () => {
  // 触发父组件的关闭函数
  emit("handleBeforeClose");
  emit("update:coalQualityMaintenanceDialogFormVisible", false);
};
const rules = reactive({
  supplierName: [
    { required: true, message: "请输入供货商名称", trigger: "blur" },
  ],
  identifyNumber: [
    { required: true, message: "请正确输入纳税人识别号", trigger: "blur" },
    { min: 17, max: 20, message: "请输入17-20位纳税人识别号", trigger: "blur" },
  ],
  address: [
    {
      required: true,
      message: "请选择经营地址",
      trigger: "change",
    },
  ],
  bankAccount: [{ required: true, message: "请输入银行账户", trigger: "blur" }],
  bank: [{ required: true, message: "请输入开户行", trigger: "blur" }],
  contacts: [{ required: true, message: "请输入开户行", trigger: "blur" }],
  contactsPhone: [
    { required: true, message: "请输入联系人", trigger: "blur" },
    { min: 11, max: 11, message: "请输入11位联系人电话", trigger: "blur" },
  ],
});
</script>
<style lang="sass" scoped>
</style>